﻿using System.IO.IsolatedStorage;
using System.Collections.Generic;
using System;


namespace Samples
{
    public class CacheIndex
    {
        private const string XAPCACHENAME = "XapCache";
        private Dictionary<string, object> m_ItemsIndex;

        public CacheIndex()
        {
            IsolatedStorageSettings iss = IsolatedStorageSettings.ApplicationSettings;
            if (iss.Contains(XAPCACHENAME))
            {
                m_ItemsIndex = iss[XAPCACHENAME] as Dictionary<string, object>;
            }
            else
            {
                m_ItemsIndex = new Dictionary<string, object>();
                iss[XAPCACHENAME] = m_ItemsIndex;
                iss.Save();
            }
        }

        public bool IsExpired(string xapFile)
        {
            bool expired = true;
            if (m_ItemsIndex.ContainsKey(xapFile))
            {
                DateTime dt = (DateTime)m_ItemsIndex[xapFile];

                expired = dt.AddSeconds(60) < DateTime.Now;    // Keep it for 1 minute
                if (expired)
                    Remove(xapFile);
            }

            return expired;
        }

        public void Add(string xapFile)
        {
            m_ItemsIndex[xapFile] = DateTime.Now;
            IsolatedStorageSettings iss = IsolatedStorageSettings.ApplicationSettings;
            iss.Save();                
        }

        public void Remove(string xapFile)
        {
            m_ItemsIndex.Remove(xapFile);
            IsolatedStorageSettings iss = IsolatedStorageSettings.ApplicationSettings;
            iss.Save();
        }

    }
}
