﻿using System;
using System.IO;
using System.IO.IsolatedStorage;
using System.Collections.Generic;


namespace Samples
{
    public class DownloadCache
    {
        /// <summary>
        /// Attempt to load the given XAP package from the cache.
        /// </summary>
        /// <param name="file">XAP file</param>
        /// <returns>Stream to the XAP package</returns>
        public static Stream Load(string file)
        {
            IsolatedStorageFile iso = IsolatedStorageFile.GetUserStoreForApplication();

            if (!iso.FileExists(file))
            {
                iso.Dispose();
                return null;
            }

            // Check some expiration policy
            // File information is not available to Silverlight applications.
            // You might want to create a sort of index with entry date
            CacheIndex m_Index = new CacheIndex();
            if (!m_Index.IsExpired(file))
                return iso.OpenFile(file, FileMode.Open);

            // No load date available: reload
            iso.Dispose();
            return null;
        }

        /// <summary>
        /// Write a XAP file with the content of the specified stream.
        /// </summary>
        /// <param name="xapName">Name of the package (file+ext)</param>
        /// <param name="xapStream">Stream with the content to save</param>
        public static void Add(string xapName, Stream xapStream)
        {
            IsolatedStorageFile iso = IsolatedStorageFile.GetUserStoreForApplication();
            if (iso.FileExists(xapName))
                iso.DeleteFile(xapName);
            IsolatedStorageFileStream fs = new IsolatedStorageFileStream(xapName, FileMode.CreateNew, iso);

            byte[] buffer = new byte[32768];  
            int bytesRead;
            while ((bytesRead = xapStream.Read(buffer, 0, buffer.Length)) != 0)  
            {  
                fs.Write(buffer, 0, bytesRead);
            }
            fs.Close();
            iso.Dispose();

            // Update index (overwrite if already exists)
            CacheIndex m_Index = new CacheIndex();
            m_Index.Add(xapName);

        }
    }
}
